================
Pulsar
================


Concurrent framework for Python.

.. toctree::
   :maxdepth: 1

   overview
   design
   faq
   advantage
   tutorials/index
   api/index
   changelog
   settings
   pics

.. _apps-framework:

Applications
=========================

Pulsar applications are built on top of pulsar concurrent framework and are
located in the :mod:`pulsar.apps` module.

.. toctree::
   :maxdepth: 1

   apps/socket
   apps/wsgi/index
   apps/data/index
   apps/tasks
   apps/test
   apps/shell
   apps/rpc
   apps/websockets
   apps/http
   apps/pulse
   apps/ds
   apps/greenio
